==> huaweicloudsdkcc-3.1.104-py2.py3-none-any.whl: huaweicloudsdkcc/v3/model/bandwidth_package_id.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class BandwidthPackageId:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'bandwidth_package_id': 'str'
    }

    attribute_map = {
        'bandwidth_package_id': 'bandwidth_package_id'
    }

    def __init__(self, bandwidth_package_id=None):
        """BandwidthPackageId

        The model defined in huaweicloud sdk

        :param bandwidth_package_id: 资源ID标识符。
        :type bandwidth_package_id: str
        """
        
        

        self._bandwidth_package_id = None
        self.discriminator = None

        self.bandwidth_package_id = bandwidth_package_id

    @property
    def bandwidth_package_id(self):
        """Gets the bandwidth_package_id of this BandwidthPackageId.

        资源ID标识符。

        :return: The bandwidth_package_id of this BandwidthPackageId.
        :rtype: str
        """
        return self._bandwidth_package_id

    @bandwidth_package_id.setter
    def bandwidth_package_id(self, bandwidth_package_id):
        """Sets the bandwidth_package_id of this BandwidthPackageId.

        资源ID标识符。

        :param bandwidth_package_id: The bandwidth_package_id of this BandwidthPackageId.
        :type bandwidth_package_id: str
        """
        self._bandwidth_package_id = bandwidth_package_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BandwidthPackageId):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcc-3.1.126-py2.py3-none-any.whl: huaweicloudsdkcc/v3/model/bandwidth_package_id.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class BandwidthPackageId:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'bandwidth_package_id': 'str'
    }

    attribute_map = {
        'bandwidth_package_id': 'bandwidth_package_id'
    }

    def __init__(self, bandwidth_package_id=None):
        """BandwidthPackageId

        The model defined in huaweicloud sdk

        :param bandwidth_package_id: 带宽包实例ID。
        :type bandwidth_package_id: str
        """
        
        

        self._bandwidth_package_id = None
        self.discriminator = None

        self.bandwidth_package_id = bandwidth_package_id

    @property
    def bandwidth_package_id(self):
        """Gets the bandwidth_package_id of this BandwidthPackageId.

        带宽包实例ID。

        :return: The bandwidth_package_id of this BandwidthPackageId.
        :rtype: str
        """
        return self._bandwidth_package_id

    @bandwidth_package_id.setter
    def bandwidth_package_id(self, bandwidth_package_id):
        """Sets the bandwidth_package_id of this BandwidthPackageId.

        带宽包实例ID。

        :param bandwidth_package_id: The bandwidth_package_id of this BandwidthPackageId.
        :type bandwidth_package_id: str
        """
        self._bandwidth_package_id = bandwidth_package_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BandwidthPackageId):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
